# je_auto_control

---

### JE Auto Control as a tool for GUI Testing 
#### Features
* Image Detect
* Keyboard Event
* Mouse Event
* Screen 
* Action file and executor
* Record Event
* CLI with action file
* timeout

---

[![CircleCI](https://circleci.com/gh/JE-Chen/AutoControl/tree/main.svg?style=svg)](https://circleci.com/gh/JE-Chen/AutoControl/tree/main)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/python-jeautocontrol/badge/?version=latest)](https://python-jeautocontrol.readthedocs.io/en/latest/?badge=latest)

documentation available at [https://python-jeautocontrol.readthedocs.io/en/latest/](https://python-jeautocontrol.readthedocs.io/en/latest/)

## install

```
pip install je_auto_control
```

## Info

* requirement
    * Python 3.5 & later
    * pip 19.3 & later


* Dev env
    * windows 11
    * osx 11 big sur
    * ubuntu 20.0.4


* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B and 4B
